from logger import logger
from time_functions import btc_unix_time_millis


def search_gpg_key(gpg_key, api):
    # TODO: refactor asyncio
    try:
        global r
        request = api.request("search/tweets", {"q": gpg_key})
        try:
            with open(gpg_key + ":" + btc_unix_time_millis(), "w+") as f:
                f.write(request.text)
                f.close
        except Exception:
            logger.info("TRY GPGR FAILED!")
            pass
    except Exception:
        logger.info("GPGR SEARCH FAILED!")
        pass



#!/usr/bin/env python3
import asyncio
import os
import shutil
import time

import aiohttp
import blockcypher

from logger import logger

genesis_time = 1231006505


async def touch_time(time):
    f = open(os.getcwd() + "/BLOCK_TIME", "w")
    f.write("" + str(time) + "\n")
    f.close()


def move_block_time():
    try:
        shutil.move(os.getcwd() + "/BLOCK_TIME", os.getcwd() + "/OLD_BLOCK_TIME")
    except Exception:
        logger.info("moveblock_time() failed!")
        touch_time()
        pass


def get_millis():
    global millis
    millis = int(round(time.time() * 1000))
    return millis


def get_seconds():
    global seconds
    seconds = int(round(time.time()))
    return seconds


def blockcypher_height():
    try:
        # block_cypher = blockcypher.get_latest_blockcypher_height(coin_symbol='btc')
        block_cypher = blockcypher.get_latest_blockcypher_height()
        blockcypher_height = repr(block_cypher)
        f = open("BLOCK_TIME", "w")
        f.write("" + blockcypher_height + "\n")
        f.close()
        return int(blockcypher_height)
    except Exception:
        return 0
        pass


def btc_time():
    # TODO: ADD AS MANY SOURCES FOR btc_time() AS POSSIBLE!!!
    mempool_loop = asyncio.new_event_loop()
    BTC_TIME = mempool_loop.run_until_complete(mempool_height())
    # assert int(BTC_TIME) >= int(blockcypher_height())
    return int(BTC_TIME)


def btc_unix_time_millis():
    global SESSION_ID
    SESSION_ID = str(btc_time()) + ":" + str(get_millis())
    f = open("SESSION_ID", "w")
    f.write("" + SESSION_ID + "\n")
    f.close()
    f = open("SESSION_ID.lock", "w")
    f.write("" + SESSION_ID + "\n")
    f.close()
    return SESSION_ID


def BTC_UNIX_TIME_SECONDS():
    return str(btc_time()) + ":" + str(get_seconds())


def unix_time_millis():
    global unix_time_millis
    unix_time_millis = str(get_millis())
    return unix_time_millis


def UNIX_TIME_SECONDS():
    global unix_time_seconds
    unix_time_seconds = str(get_seconds())
    return unix_time_seconds


def NETWORK_MODULUS():
    # internal time stamping mechanism
    # rolling deterministic time field:
    # (current_time - genesis time) yields time from bitcoin genesis block
    # we use the current block height to calculate a modulus
    # source of deterministic entropy
    # get_millis() is known to the GPGS and GPGR
    # GENESIS_TIME is well known
    # btc_time() block height message was contructed is known to GPGR and GPGS
    # TODO: add functions to reconstruct :WEEBLE:WOBBLE: based on these values
    NETWORK_MODULUS = (
        get_millis() - genesis_time) % btc_time()
    f = open("NETWORK_MODULUS", "w")
    f.write("" + str(NETWORK_MODULUS) + "\n")
    f.close()
    return NETWORK_MODULUS


def NETWORK_WEEBLE_WOBBLE():
    # :WEEBLE:WOBBLE: construction
    NETWORK_WEEBLE_WOBBLE = str(
        ":" + str(NETWORK_WEEBLE()) + ":" + str(NETWORK_WOBBLE()) + ":"
    )
    f = open("NETWORK_WEEBLE_WOBBLE", "w")
    f.write("" + str(NETWORK_WEEBLE_WOBBLE) + "\n")
    f.close()
    return NETWORK_WEEBLE_WOBBLE


def NETWORK_WEEBLE():
    # (current_time - genesis time) yields time from bitcoin genesis block
    # dividing by number of blocks yields an average time per block
    NETWORK_WEEBLE = int(
        (get_millis() - genesis_time) / btc_time()
    )
    f = open("NETWORK_WEEBLE", "w")
    f.write("" + str(NETWORK_WEEBLE) + "\n")
    f.close()
    return NETWORK_WEEBLE


def NETWORK_WOBBLE():
    # wobble is the remainder of the weeble_wobble calculation
    # source of deterministic entropy
    NETWORK_WOBBLE = str(float((get_millis() - genesis_time) / btc_time() % 1)).strip("0.")
    f = open("NETWORK_WOBBLE", "w")
    f.write("" + str(NETWORK_WOBBLE) + "\n")
    f.close()
    return int(NETWORK_WOBBLE)


async def fetch(session, url):
    async with session.get(url) as response:
        return await response.text()


async def mempool_height():
    async with aiohttp.ClientSession() as session:
        url = "https://mempool.space/api/blocks/tip/height"
        height = await fetch(session, url)
        return height


loop = asyncio.new_event_loop()
# loop = asyncio.get_event_loop()
loop.run_until_complete(mempool_height())
loop.run_until_complete(touch_time(btc_time()))

logger.info(":NETWORK_MODULUS:" + str(NETWORK_MODULUS()) + ":")
logger.info(":NETWORK_WEEBLE:" + str(NETWORK_WEEBLE()) + ":")
logger.info(":NETWORK_WOBBLE:" + str(NETWORK_WOBBLE()) + ":")
logger.info(":NETWORK_WEEBLE_WOBBLE" + str(NETWORK_WEEBLE_WOBBLE()))



#!/usr/bin/env python3
from hex_message_digest import hex_message_digest
from logger import logger
from time_functions import btc_time, unix_time_millis

LOGGER = True
HEX_LOGGER = True


def message_header(GPGR, MESSAGE, GPGS, LOC):
    # the HEADER is prepended with GPGR
    # the HEADER is appended with GPGS
    DIGEST = hex_message_digest(GPGR, MESSAGE, GPGS)
    if LOGGER:
        logger.info(DIGEST)
    # TODO branch will be dynamic based on message tree - tbd
    # LOC isnt nesseccsarally a web asset
    # LOC is just a string - maybe a geo location for example
    BRANCH = "main"
    LOC = "https://github.com/0x20bf-org/0x20bf/blob/" + BRANCH
    # LOC is appended on to DIGEST
    HEADER = str(
        ":"
        + GPGR
        + ":"
        + DIGEST
        + ":"
        + str(btc_time())
        + ":"
        + unix_time_millis()
        + ":"
        + GPGS
        + ":"
        + LOC
        + ":"
    )

    if LOGGER:
        logger.info(HEADER)
    # ":GPGR:DIGEST:btc_time:unix_time_millis:GPGS:LOC:"
    return HEADER


def test_message_header():
    logger.info("test_message_header()")
    GPGR = "4DC9817F"  # bitkarrot
    logger.info(GPGR)
    GPGS = "BB06757B"  # randymcmillan
    logger.info(GPGS)
    MESSAGE = "text human readable message"
    if HEX_LOGGER:
        logger.info(hex_message_digest(GPGR, MESSAGE, GPGS))
    logger.info(str(message_header(GPGR, MESSAGE, GPGS, "test/location")))
    return message_header(GPGR, MESSAGE, GPGS, "test/location")


logger.info(test_message_header())



import configparser

global AT
global ATS
global CAK
global CASK

config = configparser.ConfigParser()
config.read("configs.ini")
config.sections()
config.get("DEFAULTSECT", "", fallback=False)
config.get("LOGGERDEFAULTS", "", fallback=False)
config.get("USERDEFAULTS", "", fallback=False)


if config.get("[USERDEFAULTS]", "tweet"):
    twitter_api = configparser.ConfigParser()
    twitter_api.read("twitter.ini")
    twitter_api.sections()
    twitter_api.get("TWITTERAPI", "", fallback=0)
    AT = twitter_api.get("[TWITTERAPI]", "access_token")
    ATS = twitter_api.get("[TWITTERAPI]", "access_token_secret")
    CAK = twitter_api.get("[TWITTERAPI]", "consumer_api_key")
    CASK = twitter_api.get("[TWITTERAPI]", "consumer_api_secret_key")
else:
    AT = config.get("[USERDEFAULTS]", "tweet")
    ATS = config.get("[USERDEFAULTS]", "tweet")
    CAK = config.get("[USERDEFAULTS]", "tweet")
    CASK = config.get("[USERDEFAULTS]", "tweet")



#!/usr/bin/env python3
from configs import DATA_LOGGER, LOGGER
from TwitterAPI import TwitterAPI

from logger import logger
from time_functions import BTC_TIME, BTC_UNIX_TIME_MILLIS
from twitter_api_keys import AT, ATS, CAK, CASK

api = TwitterAPI(CAK, CASK, AT, ATS)
# if (LOGGER): print(api)


def set_old_block_time():
    f = open("OLD_BLOCK_TIME", "w")
    f.write(str(BTC_TIME()))
    f.close()


def get_old_block_time():
    f = open("OLD_BLOCK_TIME", "r")
    OBT = str(f.read())
    f.close()
    if DATA_LOGGER:
        logger.info(OBT)  # unsecure
    set_old_block_time()
    return OBT


def tweet_block_time():
    # print(BTC_TIME())
    # print(get_old_block_time())
    # print(int(BTC_TIME()) != int(get_old_block_time()))
    # set_old_block_time()
    if int(BTC_TIME()) != int(get_old_block_time()):
        request = api.request("statuses/update", {"status": BTC_UNIX_TIME_MILLIS()})
        if LOGGER:
            logger.info(request)
        if request.status_code == 200:
            logger.info("api.request SUCCESS")
        else:
            logger.info("api.request FAILURE")
    else:
        logger.info("tweetblock_time() FAILURE")


if __name__ == "__main__":

    tweet_block_time()



#!/usr/bin/env python3
import asyncio
import configparser
import os

import aiohttp

from logger import logger

# get the path to config.ini
config_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'config.ini')

# check if the path is to a valid file
if not os.path.isfile(config_path):
    print('BadConfigError')  # not a standard python exception

config = configparser.ConfigParser()
config.read(config_path)
# config.read("configs.ini")
config.sections()
config.get("DEFAULTS", "", fallback=False)


MEMPOOL_LOGGER = True


async def fetch(session, url):
    async with session.get(url) as response:
        return await response.text()


async def mempool_height():
    async with aiohttp.ClientSession() as session:
        url = "https://mempool.space/api/blocks/tip/height"
        height = await fetch(session, url)
        if MEMPOOL_LOGGER:
            logger.info(height)
        return height


loop = asyncio.new_event_loop()
# loop = asyncio.get_event_loop()
loop.run_until_complete(mempool_height())



#!/usr/bin/env python3
import asyncio
import time

import blockcypher

from logger import logger
from mempool_height import mempool_height

LOGGER = True

millis = int(round(time.time() * 1000))
seconds = int(round(time.time()))

try:
    block_time = blockcypher.get_latest_block_height(coin_symbol="btc")
    block_height = repr(block_time)
    f = open("BLOCKCYPHER_HEIGHT", "w")
    f.write("" + block_height + "\n")
    f.close()
    if LOGGER:
        logger.info(block_time)
        logger.info(block_height)
except Exception:
    loop = asyncio.new_event_loop()
    block_height = loop.run_until_complete(mempool_height())
    if LOGGER:
        logger.info(str(block_height))
    f = open("MEMPOOL_SPACE_HEIGHT", "w")
    f.write("" + block_height + "\n")
    f.close()
    pass
# TODO: add more redundant block height checks



#!/usr/bin/env python3
import argparse
import configparser
import hashlib
import sys

import psutil

# from search_gpg_key import search_gpg_key
# from time_functions import btc_time, unix_time_millis
import time_functions as tf
from delimiter_stripper import delimiter_stripper
from logger import logger

# import os

# from TwitterAPI import TwitterAPI

# from TwitterAPI import TwitterAPI


global user
global is_macos
global is_linux
global is_windows
user = psutil.Process().username()
is_macos = psutil.MACOS
is_linux = psutil.LINUX
# windows support not planned - but PRs are welcome
is_windows = psutil.WINDOWS

# Setup logging
global logger
global os_logger
global data_logger
global hex_logger
global genesis_time
global time_logger
global mempool_logger

# global variables
# we leave comments in PROTOCOL format ie. GPGR DIGEST etc...
global HEADER
global DIGEST
global BODY
global DATA
global TEST_256
global GPGR
global GPGS
global MESSAGE
global GOLDEN_RATIO

global tweet

# # REF: https://docs.python.org/3/library/configparser.html
#
# # get the path to config.ini
# sys.path.insert(0, '.')
# sys.path.insert(1, '0x20bf')
# sys.path.insert(2, '../0x20bf')
# config_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'config.ini')
#
# # check if the path is to a valid file
# if not os.path.isfile(config_path):
#     print('BadConfigError')  # not a standard python exception
#
# config = configparser.ConfigParser()
# config.read(config_path)
# # config.read("configs.ini")
# config.sections()
# config.get("DEFAULTS", "", fallback=False)
#
#
# if config.getboolean("DEFAULTS", "tweet"):
#     twitter_api = configparser.ConfigParser()
#     twitter_api.read("configs.ini")
#     twitter_api.sections()
#     twitter_api.get("twitter", "", fallback=0)
#     AT = twitter_api.get("twitter", "access_token")
#     ATS = twitter_api.get("twitter", "access_token_secret")
#     CAK = twitter_api.get("twitter", "consumer_api_key")
#     CASK = twitter_api.get("twitter", "consumer_api_secret_key")
#     api = TwitterAPI(CAK, CASK, AT, ATS)


def test_hash_lib():
    TEST_256 = hashlib.sha256()
    # empty string reserved for protocol
    assert TEST_256.digest_size == pow(2, 5)
    assert TEST_256.block_size == pow(2, 6)
    assert (
        TEST_256.hexdigest()
        == "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855"
    )
    return TEST_256.hexdigest()


def HEX_MESSAGE_TREE(recipient, sender):
    recipient = delimiter_stripper(recipient)
    sender = delimiter_stripper(sender)

    n_256 = hashlib.sha256()
    logger.info("n_256:")
    logger.info(n_256.hexdigest())
    # empty string reserved for protocol
    assert n_256.hexdigest() == test_hash_lib()

    # SHA256() + GPGR
    n_256.update(bytes(recipient, "utf-8"))
    # if (hex_logger): logger.info(n_256.digest())
    logger.info("n_256 + recipient:")
    logger.info(n_256.hexdigest())
    # if (hex_logger): logger.info(n_256.digest_size)
    # if (hex_logger): logger.info(n_256.block_size)

    # SHA256() + GPGR+GPGS
    n_256.update(bytes(sender, "utf-8"))
    # if (hex_logger): logger.info(n_256.digest())
    # if (hex_logger): logger.info(n_256.hexdigest())
    # if config.getboolean("DEFAULTS", "hex_logger"):
    logger.info("n_256 + recipient+sender:")
    logger.info(n_256.hexdigest())
    # if (hex_logger): logger.info(n_256.digest_size)
    # if (hex_logger): logger.info(n_256.block_size)

    # TODO: populate message tree
    # if config.getboolean("DEFAULTS", "hex_logger"):
    logger.info(n_256.hexdigest())

    return n_256.hexdigest()


def HEX_MESSAGE_DIGEST(recipient, message, sender):
    recipient = delimiter_stripper(recipient)
    sender = delimiter_stripper(sender)
    message = delimiter_stripper(message)

    n_256 = hashlib.sha256()
    # empty string reserved for protocol
    assert n_256.hexdigest() == test_hash_lib()

    # SHA256() + GPGR
    n_256.update(bytes(recipient, "utf-8"))
    logger.info(n_256.hexdigest())

    # SHA256() + GPGR+MESSAGE
    n_256.update(bytes(message, "utf-8"))
    logger.info(n_256.hexdigest())

    # SHA256() + GPGR+MESSAGE+GPGS
    n_256.update(bytes(sender, "utf-8"))
    logger.info(n_256.hexdigest())

    # TODO: populate message tree
    logger.info(n_256.hexdigest())

    return n_256.hexdigest()


def message_header():
    # the HEADER is prepended with GPGR
    # the HEADER is appended with GPGS
    DIGEST = HEX_MESSAGE_DIGEST(GPGR, MESSAGE, GPGS)
    LOC = (
        "https://github.com/0x20bf-org/0x20bf/blob/main/"
        + GPGR
        + DIGEST
        + str(tf.btc_time())
        + str(tf.unix_time_millis())
        + GPGS
        + ".txt.gpg"
    )
    # LOC is appended on to DIGEST
    HEADER = str(
        ":"
        + GPGR
        + ":"
        + DIGEST
        + ":"
        + str(tf.btc_time())
        + ":"
        + str(tf.unix_time_millis())
        + ":"
        + GPGS
        + ":"
        + LOC
        + ":"
    )

    if logger:
        logger.info(HEADER)
    # HEADER_STRUCTURE = str(":GPGR:DIGEST:btc_time:unix_time_millis:GPGS:LOC:")
    return HEADER


def send_message(tweet, api):
    header = message_header()
    # body = message_body()
    if logger:
        logger.info(header)
    if tf.btc_time() != 0:
        if tweet:
            request = api.request("statuses/update", {"status": header})
            if request.status_code == 200:
                logger.info("api.request SUCCESS")
            else:
                logger.info("api.request FAILURE")
        else:
            logger.info("tweet=" + str(tweet))
    else:
        logger.info("tweetblock_time() FAILURE")


# logger.info(BTC_unix_time_millis())

GPGR = "4DC9817F"  # bitkarrot
logger.info(GPGR)
GPGS = "BB06757B"  # randymcmillan
logger.info(GPGS)
MESSAGE = "text human readable message"


def log_os():
    if is_macos:
        logger.info(str("is_macos"))

    if is_linux:
        logger.info(str("is_linux"))

    if is_windows:
        logger.info(str("is_windows"))


def main(args):
    # parse values from a configuration file if provided and use those as the
    # default values for the argparse arguments
    config_argparse = argparse.ArgumentParser(prog=__file__, add_help=False)
    config_argparse.add_argument(
        "-c", "--config-file", help="path to configuration file"
    )
    config_args, _ = config_argparse.parse_known_args(args)

    defaults = {
        "default_port": 8383,
        "tweet": False,
        "text_message": False,
        "search": False,
        "logger": False,
        "os_logger": True,
        "data_logger": False,
        "hex_logger": False,
        "time_logger": False,
        "mempool_logger": False,
        "option1": False,
        "option2": False,
    }

    if config_args.config_file:
        logger.info("Loading configuration: {}".format(config_args.config_file))
        try:
            config_parser = configparser.ConfigParser()
            with open(config_args.config_file) as f:
                config_parser.read_file(f)
            config_parser.read(config_args.config_file)
        except OSError as err:
            logger.error(str(err))
            sys.exit(1)

        defaults.update(dict(config_parser.items("options")))

    # parse the program's main arguments using the dictionary of defaults and
    # the previous parsers as "parent' parsers
    parsers = [config_argparse]
    main_parser = argparse.ArgumentParser(prog=__file__, parents=parsers)
    main_parser.set_defaults(**defaults)

    # args still need to be set up
    main_parser.add_argument("-dp", "--default_port")
    main_parser.add_argument("-l", "--logger")
    main_parser.add_argument("-ol", "--os_logger")
    main_parser.add_argument("-dl", "--data_logger")
    main_parser.add_argument("-hl", "--hex_logger")
    main_parser.add_argument("-tl", "--time_logger")
    main_parser.add_argument("-mpl", "--mempool_logger")
    main_parser.add_argument("-s", "--search")
    main_parser.add_argument("-t", "--tweet")
    main_parser.add_argument("-1", "--option1")
    main_parser.add_argument("-2", "--option2")
    main_parser.add_argument("-tm", "--text_message")
    main_args = main_parser.parse_args(args)
    print(main_args.option1)
    print(main_args.option2)
    print(main_args.logger)
    print(main_args.tweet)
    if main_args:
        tweet = main_args.tweet
        logger.info(tweet)
        text_message = main_args.text_message
        logger.info(text_message)
        mempool_logger = main_args.mempool_logger
        logger.info(mempool_logger)
        hex_logger = main_args.hex_logger
        if hex_logger:
            logger.info(HEX_MESSAGE_DIGEST(GPGR, MESSAGE, GPGS))
            HEX_MESSAGE_TREE(GPGR, GPGS)
            HEX_MESSAGE_DIGEST(GPGR, MESSAGE, GPGS)


if __name__ == "__main__":
    GPGR = "4DC9817F"  # bitkarrot
    logger.info(GPGR)
    GPGS = "BB06757B"  # randymcmillan
    logger.info(GPGS)
    MESSAGE = "text human readable message"
    main(sys.argv[1:])



import hashlib

from delimiter_stripper import delimiter_stripper
from logger import logger
from time_functions import btc_time, unix_time_millis

LOGGER = True
HEX_LOGGER = True


def test_hash_lib_sha256():
    TEST_256 = hashlib.sha256()
    # empty string reserved for protocol
    assert TEST_256.digest_size == pow(2, 5)
    assert TEST_256.block_size == pow(2, 6)
    assert (
        TEST_256.hexdigest()
        == "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855"
    )
    return TEST_256.hexdigest()


def test_hash_lib_ripemd160():
    TEST_160 = hashlib.new("ripemd160")
    assert TEST_160.digest_size == 20
    assert TEST_160.block_size == pow(2, 6)
    # if HEX_LOGGER:
    #     logger.info(TEST_160.hexdigest())
    #     logger.info(str(TEST_160.digest_size))
    #     logger.info(str(TEST_160.block_size))
    # empty string reserved for protocol
    assert TEST_160.hexdigest() == "9c1185a5c5e9fc54612808977ee8f548b2258d31"
    return TEST_160.hexdigest()


def hex_message_digest(recipient, message, sender):

    test_hash_lib_ripemd160()
    recipient = delimiter_stripper(recipient)
    message = delimiter_stripper(message)
    sender = delimiter_stripper(sender)

    n_160 = hashlib.new("ripemd160")
    # empty string reserved for protocol
    assert n_160.hexdigest() == test_hash_lib_ripemd160()

    if HEX_LOGGER:
        logger.info(str(":RIPEMD160:") + n_160.hexdigest() + str(":"))

    # RIPEMD160(RIPEMD160() + GPGR)
    n_160.update(bytes(recipient, "utf-8"))
    if HEX_LOGGER:
        logger.info(str(":RIPEMD160:") + n_160.hexdigest() + str(":"))

    # RIPEMD160(RIPEMD160(RIPEMD160() + GPGR) + message)
    n_160.update(bytes(message, "utf-8"))
    if HEX_LOGGER:
        logger.info(str(":RIPEMD160:") + n_160.hexdigest() + str(":"))

    # RIPEMD160(RIPEMD160(RIPEMD160() + GPGR) + message) + GPGS)
    n_160.update(bytes(sender, "utf-8"))
    if HEX_LOGGER:
        logger.info(str(":RIPEMD160:") + n_160.hexdigest() + str(":"))

    return n_160.hexdigest()


def message_header():
    # the HEADER is prepended with GPGR
    # recipient comes first - GPGR
    # the HEADER is appended with GPGS then lastly LOC (location)
    # HEADER_STRUCTURE = str(":GPGR:DIGEST:BTC_TIME:UNIX_TIME_MILLIS:GPGS:LOC:")
    DIGEST = hex_message_digest(GPGR, MESSAGE, GPGS)
    # TODO GPGR short gpg id determines the branch of the repo
    # the GPGR short id name space will be shared with nodes
    # share_public_keyring() will trigger a node to exchange
    # AFTER it has been interogated and verified
    # upon git_request(GPGR) - tbd
    LOC = (
        "https://github.com/0x20bf-org/0x20bf/blob/"
        + GPGR
        + DIGEST
        + btc_time()
        + unix_time_millis()
        + GPGS
        + ".txt.gpg"
    )
    # LOC is appended on to DIGEST
    HEADER = str(
        ":"
        + GPGR
        + ":"
        + DIGEST
        + ":"
        + btc_time()
        + ":"
        + unix_time_millis()
        + ":"
        + GPGS
        + ":"
        + LOC
        + ":"
    )

    if LOGGER:
        logger.info(HEADER)
    # HEADER_STRUCTURE = str(":GPGR:DIGEST:BTC_TIME:UNIX_TIME_MILLIS:GPGS:LOC:")
    return HEADER


# logger.info(BTC_UNIX_TIME_MILLIS())

GPGR = "4DC9817F"  # bitkarrot
# logger.info(GPGR)
GPGS = "BB06757B"  # randymcmillan
# logger.info(GPGS)
MESSAGE = "text human readable message"
# if HEX_LOGGER:
# logger.info(hex_message_digest(GPGR, MESSAGE, GPGS))
hex_message_digest(GPGR, MESSAGE, GPGS)



#!/usr/bin/env python3
import sys

sys.path.append(".")
sys.path.append("/usr/local/lib/python3.10/site-packages")
sys.path.append("/usr/local/lib/python3.9/site-packages")
sys.path.append("/usr/local/lib/python3.8/site-packages")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['0x20bf']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML==5.4.1',
 'aiohttp==3.7.4.post0',
 'gnupg>=2.3.1,<3.0.0',
 'pre_commit>=2.1.0,<3.0.0']

setup_kwargs = {
    'name': '0x20bf',
    'version': '0.0.1',
    'description': '0x20bf: This document proposes an Internet standards track protocol for transporting, broadcasting and syndication of messages over common internet communications channels. The distribution of all documents related to this proposal are unlimited and unencumbered by any LICENSE, but some are included anyway.',
    'long_description': None,
    'author': 'randymcmillan',
    'author_email': 'randy.lee.mcmillan@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
